<template>
  <gree-view bg-color="#F4F4F4">
    <gree-page class="page-offline">
      <gree-header :left-options="{ preventGoBack: true }" @on-click-back="goBack"
        >{{ devname }}
        <i class="iconfont iconfont-gengduo" slot="right" @click="moreInfo" />
      </gree-header>
      <div class="page-main">
        <!-- 图片 -->
        <div class="page-main-img">
          <img src="@assets/img/offllne_tip.png" />
        </div>
        <!-- 家用文案 -->
        <div class="page-main-txt" v-text="$language('offline.txt')" />
        <div class="page-main-text" v-if="isHousehold">
          <p v-text="'1.设备是否连接上电源？'" />
          <p v-text="'2.设备是否关闭了WiFi功能？按空调遥控器上的“WiFi”按键打开。'" />
          <p v-text="'3.拔掉电源插头再插上试试看。'" />
          <p v-text="'4.路由器名称和密码是否有变动？'" />
          <p v-text="'5.核实是否误操作导致设备重置'" />
          <p>
            {{ '6.如上述情况均排除，请尝试' }}
            <a :class="{ link: myHome }" @click="onReaddDevice">{{ $language('offline.tips6') }}</a>
          </p>
          <!-- <p v-text="'如排查以上原因后仍未恢复连接，您可以尝试重置WiFi'" /> -->
        </div>
        <!-- 驻车空调文案 -->
        <div class="page-main-text" v-else-if="isVehicle">
          <p v-text="'1.驻车空调是否连接上电源？'" />
          <p v-text="'2.驻车空调断电隔5秒再上电试试看。'" />
          <p v-text="'3.请检查手机是否开启蓝牙？'" />
          <p v-text="'4.请检查驻车空调与手机距离是否太远？'" />
          <!-- <p v-text="'5.核实是否误操作导致设备重置'" />
          <p>
            {{ '6.如上述情况均排除，请尝试' }}
            <a :class="{ link: myHome }" @click="onReaddDevice">{{ $language('offline.tips6') }}</a>
          </p> -->
          <!-- <p v-text="'如排查以上原因后仍未恢复连接，您可以尝试重置WiFi'" /> -->
        </div>
        <!-- 商用文案 -->
        <!-- <div class="page-main-txt" v-text="$language('offline.txt')" /> -->
        <div class="page-main-text" v-else>
          <p v-text="'1.' + $language('offline.tips1')" />
          <p v-text="'2.' + $language('offline.tips2')" />
          <p v-text="'3.' + $language('offline.tips3')" />
          <p v-text="'4.' + $language('offline.tips4')" />
          <p>
            {{ '5.' + $language('offline.tips5') }}
            <a :class="{ link: myHome }" @click="onReaddDevice">{{ $language('offline.tips6') }}</a>
          </p>
        </div>
      </div>
    </gree-page>
  </gree-view>
</template>

<script>
import { mapState, mapGetters } from 'vuex';
import { closePage, startCatalogConfigActivity, editDevice, getIsMyHome } from '@PluginInterface';
import { Header, Toast, Radio, RadioList, Switch, List, Item } from 'gree-ui';

export default {
  components: {
    [Header.name]: Header,
    [Radio.name]: Radio,
    [RadioList.name]: RadioList,
    [Switch.name]: Switch,
    [List.name]: List,
    [Item.name]: Item,
    [Toast.name]: Toast
  },
  data() {
    return {
      myHome: true
    };
  },
  created() {
    this.isMyHome();
  },
  computed: {
    ...mapState('control', {
      mac: state => state.mac,
      devname: state => state.deviceInfo.name,
      isOffline: state => state.deviceInfo.deviceState
    }),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    isHousehold() {
      return Object.keys(this.statusMap).includes('household');
    },
    isVehicle() {
      return Object.keys(this.statusMap).includes('vehicle');
    }
  },
  methods: {
    /**
     * @description 返回键
     */
    goBack() {
      closePage();
    },
    moreInfo() {
      editDevice(this.mac);
    },
    isMyHome() {
      getIsMyHome().then(_res => {
        const result = JSON.parse(_res);
        this.myHome = result.isMyHome;
        console.log('isMyHome:', this.myHome);
      });
    },
    onReaddDevice() {
      startCatalogConfigActivity();
    }
  }
};
</script>

<style lang="scss">
.page-offline {
  .page-content {
    overflow: hidden;
    background-color: white;
  }
  .gree-header {
    background-color: transparent;
    background-image: none;
    &-left {
      height: 100%;
      display: flex !important;
      align-items: center !important;
    }
  }
  .page-main {
    position: relative;
    top: 0;
    height: 100%;
    width: 100%;
    background-color: white;
    &-img {
      position: relative;
      margin-top: 210px;
      width: 100%;
      height: 543px;
      display: flex;
      justify-content: center;
      img {
        height: 100%;
        width: 867px;
      }
    }
    &-txt {
      position: relative;
      width: 100%;
      margin-top: 45px;
      text-align: center;
      font-size: 36px;
      color: rgba(152, 152, 152, 1);
    }
    &-text {
      width: auto;
      max-width: 70%;
      margin: auto;
      padding-top: 200px;
      p {
        font-size: 46px;
        // margin-left: 180px;
        margin-bottom: 0;
        color: rgba(152, 152, 152, 1);
        a {
          display: block;
          color: #989899;
          pointer-events: none;
          &.link {
            color: #009dff;
            text-decoration: underline;
            pointer-events: auto;
          }
        }
      }
    }
    // &-tip {
    //   position: relative;
    //   width: 100%;
    //   margin-top: 170px;
    //   margin-left: 132px;
    //   font-size: 36px;
    //   letter-spacing: 0.5px;
    //   line-height: 60px;
    //   color: rgba(152, 152, 152, 1);
    //   span {
    //     color: rgba(97, 156, 231, 1);
    //     border-bottom: 1px solid rgba(97, 156, 231, 1);
    //   }
    // }
    // &-bottom {
    //   position: relative;
    //   width: 100%;
    //   font-size: 36px;
    //   text-align: center;
    //   margin-top: 240px;
    //   color: rgba(64, 70, 87, 1);
    // }
  }
}
</style>
